DataType

Enum DataType 

#[repr(u16)]
pub enum DataType {
Show 20 variants Boolean = 1, Int8 = 2, Int16 = 3, Int32 = 4, UInt8 = 5, UInt16 = 6, UInt32 = 7, Real32 = 8, VisibleString = 9, OctetString = 10, UnicodeString = 11, TimeOfDay = 12, TimeDifference = 13, Domain = 15, Int24 = 16, Real64 = 17, Int64 = 21, UInt24 = 22, UInt64 = 27, Other(u16),
}
Indicate the type of data stored in an object

Variants



Boolean = 1

A true false value, encoded as a single byte, with 0 for false and 1 for true



Int8 = 2

A signed 8-bit integer



Int16 = 3

A signed 16-bit integer



Int32 = 4

A signed 32-bit integer



UInt8 = 5

An unsigned 8-bit integer



UInt16 = 6

An unsigned 16-bit integer



UInt32 = 7

An unsigned 32-bit integer



Real32 = 8

A 32-bit floating point value



VisibleString = 9

An ASCII/utf-8 string



OctetString = 10

A byte string



UnicodeString = 11

A unicode string



TimeOfDay = 12

Currently Unimplemented



TimeDifference = 13

Currently Unimplemented



Domain = 15

An arbitrary byte access type for e.g. data streams, or large chunks of data. Size is typically not known at build time.



Int24 = 16

A signed 24-bit integer



Real64 = 17

A 64-bit floating point value



Int64 = 21

A signed 64-bit integer



UInt24 = 22

An unsigned 24-bit integer



UInt64 = 27

An unsigned 64-bit integer



Other(u16)

A contained for an unrecognized data type value

Implementations

Source

impl DataType

pub fn is_str(&self) -> bool

Returns true if data type is one of the string types