SubInfo

Struct SubInfo 

pub struct SubInfo {
    pub size: usize,
    pub data_type: DataType,
    pub access_type: AccessType,
    pub pdo_mapping: PdoMappable,
    pub persist: bool,
}
Information about a sub object

Fields

size: usize

The size (or max size) of this sub object, in bytes

data_type: DataType

The data type of this sub object

access_type: AccessType

Indicates what accesses (i.e. read/write) are allowed on this sub object

pdo_mapping: PdoMappable

Indicates whether this sub may be mapped to PDOs

persist: bool

Indicates whether this sub should be persisted when data is saved

Implementations

Source

impl SubInfo

pub const MAX_SUB_NUMBER: SubInfo

A shorthand value for sub0 on record and array objects

pub const fn new_u32() -> Self

Convenience function for creating a new sub-info by type

pub const fn new_u24() -> Self

Convenience function for creating a new sub-info by type

pub const fn new_u16() -> Self

Convenience function for creating a new sub-info by type

pub const fn new_u8() -> Self

Convenience function for creating a new sub-info by type

pub const fn new_i32() -> Self

Convenience function for creating a new sub-info by type

pub const fn new_i24() -> Self

Convenience function for creating a new sub-info by type

pub const fn new_i16() -> Self

Convenience function for creating a new sub-info by type

pub const fn new_i8() -> Self

Convenience function for creating a new sub-info by type

pub const fn new_f32() -> Self

Convenience function for creating a new sub-info by type

pub const fn new_visibile_str(size: usize) -> Self

Convenience function for creating a new sub-info by type

pub const fn ro_access(self) -> Self

Convenience function to set the access_type to read-only

pub const fn rw_access(self) -> Self

Convenience function to set the access_type to read-write

pub const fn const_access(self) -> Self

Convenience function to set the access_type to const

pub const fn wo_access(self) -> Self

Convenience function to set the access_type to write-only

pub const fn persist(self, value: bool) -> Self

Convenience function to set the persist value