pub struct PdoCommParameter {
pub valid: bool,
pub rtr_disabled: bool,
pub cob_id: CanId,
pub transmission_type: u8,
}Expand description
Represents a PDO Communications Parameter Object
Fields
valid: boolIndicates the PDO is valid / enabled
Note: The bit in the object itself is inverted – it’s 1 when the PDO is not valid
rtr_disabled: boolTrue if RTR is allowed on this PDO
cob_id: CanIdThe COB-ID used to send or receive the PDO
transmission_type: u8The transmission type for the PDO
It specifies when a PDO is sent or latched:
- 0: Sent in response to sync, but only after an application specific event (e.g. it may be sent when the value changes, but not when it has not)
- 1 - 240: Sent in response to every Nth sync
- 254: Event driven (application to send it whenever it wants)